/**
 * ==========================================================================
 * File:   gfl_IndexOutOfBoundsException.cpp
 * Author: Hisanao Suzuki
 * Created on 2011/12/1
 *
 * 配列やバッファサイズをオーバーするようなアクセスが発生した場合にthrowされる例外クラス
 * ==========================================================================
 */
#include <err/gfl_IndexOutOfBoundsException.h>


//-----------------------------------------------------------------------
// MESSAGE HEADER
//-----------------------------------------------------------------------
#define GFL_INDEX_OUT_OF_BOUNDS_EXCEPTION_CLASS_HEADER     ("gfl::err:IndexOutOfBoundsException")
//-----------------------------------------------------------------------


namespace gfl{
namespace err{

/** ---------------------------------------------------------------------
* @brief  コンストラクタ
* @param  message エラーメッセージを追加したい場合、文字列を渡す。
*         NULLの指定も可能。
* @param  fileName エラーが発生したファイル名
*         NULLの指定も可能。
* @param  line     エラーが発生したファイル行番号
* @param  funcName エラーが発生した関数名(省略可能)
*         NULLの指定も可能。
* @return 無し
// ---------------------------------------------------------------------*/
IndexOutOfBoundsException::IndexOutOfBoundsException( const char * message, const char *fileName, u32 line, const char* funcName )
: gfl::err::Exception( NULL, fileName, line, funcName )
{
	SetMessage( GFL_INDEX_OUT_OF_BOUNDS_EXCEPTION_CLASS_HEADER, message );
}


} // err
} // gfl

